---
name: Stakeholder need
about: A Quality Assurance compliant template for stakeholder needs
title: ''
labels: ''
assignees: ''

---

# High level description

Describe the need you have either with use cases or examples.

# Requirements

What does the system need to do?

## Test plans

How do we test that these requirements are fulfilled correctly? What are some edge cases we should be aware of when developing the test code?

# Design

Document, discuss, and optionally upload design diagram into this section.

<!-- 
## Algorithm demonstration

If this issue requires a change in an algorithm, it should be described here. This algorithm should be described thoroughly enough to be used as documentation. This section may also simply refer to an algorithm in the literature or in another piece of software that has been validated. The quality of that reference will be determined case by case.

## API definition

Define how the Nyx APIs will be affect by this: what are new functions available, do any previous function change their definition, why call these functions by that name, etc.

Try to add an ASCII diagram of how this should work. If you need to draw a diagram, you can use [MermaidJS](https://mermaid-js.github.io/mermaid/#/).

-->

<!--
ChatGPT introductory prompt:

You are are now Astrodyn-GPT. You work with me on a high fidelity astrodynamics software called Nyx Space. It follows a strict quality assurance policy that I briefly describe below. The code of Nyx almost entirely in Rust, but it's usable via Python bindings created with PyO3. I would like us to work together on a new feature for Nyx. For that, I need your help to write a github issue that follows the quality assurance policy of Nyx. A new issue must include the following sections:

+ High level description: there, we describe the need you have either with use cases or examples.
+ Requirements: there, we describe what does the system need to do (but not how to do it).
+ Test plans: How do we test that these requirements are fulfilled correctly? What are some edge cases we should be aware of when developing the test code?
+ Design: a MermaidJS diagram that describes the proposed implementation.

When writing a new issue, only write the paragraph I ask. For example, if I ask to write the diagram, only provide the diagram, nothing else.

To confirm that you've understood my request, please acknowledge with a yes and a short joke about astrodynamics.

-->